]> git.llucax.com Git - software/libev.git/blobdiff - ev_vars.h
*** empty log message ***
[software/libev.git] / ev_vars.h
index e4ece3c34eb0b45d362eeff84615e925558b5ddc..951c45d0f33e63946f49c9d1c009cd45c2c56672 100644 (file)
--- a/ev_vars.h
+++ b/ev_vars.h
@@ -2,22 +2,27 @@
 
 VARx(ev_tstamp, now_floor) /* last time we refreshed rt_time */
 VARx(ev_tstamp, mn_now)    /* monotonic clock "now" */
-VARx(ev_tstamp, ev_rt_now)
-VARx(ev_tstamp, rtmn_diff)      /* difference realtime - monotonic time */
-VARx(int, method)
-
-VARx(ev_tstamp, method_fudge) /* assumed typical timer resolution */
-VAR (method_modify, void (*method_modify)(EV_P_ int fd, int oev, int nev))
-VAR (method_poll  , void (*method_poll)(EV_P_ ev_tstamp timeout))
+VARx(ev_tstamp, rtmn_diff) /* difference realtime - monotonic time */
+VARx(int, backend)
+VARx(int, activecnt) /* total number of active events ("refcount") */
+VARx(unsigned int, loop_count); /* total number of loop iterations/blocks */
+
+VARx(ev_tstamp, backend_fudge) /* assumed typical timer resolution */
+VAR (backend_modify, void (*backend_modify)(EV_P_ int fd, int oev, int nev))
+VAR (backend_poll  , void (*backend_poll)(EV_P_ ev_tstamp timeout))
+VARx(int, backend_fd)
+
+#if !defined(_WIN32) || EV_GENWRAP
+VARx(pid_t, curpid)
+#endif
 
 VARx(int, postfork)  /* true if we need to recreate kernel state after fork */
-VARx(int, activecnt) /* number of active events */
 
 #if EV_USE_SELECT || EV_GENWRAP
-VARx(unsigned char *, vec_ri)
-VARx(unsigned char *, vec_ro)
-VARx(unsigned char *, vec_wi)
-VARx(unsigned char *, vec_wo)
+VARx(void *, vec_ri)
+VARx(void *, vec_ro)
+VARx(void *, vec_wi)
+VARx(void *, vec_wo)
 VARx(int, vec_max)
 #endif
 
@@ -30,14 +35,11 @@ VARx(int, pollidxmax)
 #endif
 
 #if EV_USE_EPOLL || EV_GENWRAP
-VARx(int, epoll_fd)
-
 VARx(struct epoll_event *, epoll_events)
 VARx(int, epoll_eventmax)
 #endif
 
 #if EV_USE_KQUEUE || EV_GENWRAP
-VARx(int, kqueue_fd)
 VARx(struct kevent *, kqueue_changes)
 VARx(int, kqueue_changemax)
 VARx(int, kqueue_changecnt)
@@ -45,6 +47,11 @@ VARx(struct kevent *, kqueue_events)
 VARx(int, kqueue_eventmax)
 #endif
 
+#if EV_USE_PORT || EV_GENWRAP
+VARx(struct port_event *, port_events)
+VARx(int, port_eventmax)
+#endif
+
 VARx(ANFD *, anfds)
 VARx(int, anfdmax)
 
@@ -60,13 +67,18 @@ VARx(struct ev_timer **, timers)
 VARx(int, timermax)
 VARx(int, timercnt)
 
+#if EV_PERIODIC_ENABLE || EV_GENWRAP
 VARx(struct ev_periodic **, periodics)
 VARx(int, periodicmax)
 VARx(int, periodiccnt)
+#endif
 
-VARx(struct ev_idle **, idles)
-VARx(int, idlemax)
-VARx(int, idlecnt)
+#if EV_IDLE_ENABLE || EV_GENWRAP
+VAR (idles, ev_idle **idles [NUMPRI])
+VAR (idlemax, int idlemax [NUMPRI])
+VAR (idlecnt, int idlecnt [NUMPRI])
+#endif
+VARx(int, idleall) /* total number */
 
 VARx(struct ev_prepare **, prepares)
 VARx(int, preparemax)
@@ -76,5 +88,17 @@ VARx(struct ev_check **, checks)
 VARx(int, checkmax)
 VARx(int, checkcnt)
 
+#if EV_FORK_ENABLE || EV_GENWRAP
+VARx(struct ev_fork **, forks)
+VARx(int, forkmax)
+VARx(int, forkcnt)
+#endif
+
+#if EV_USE_INOTIFY || EV_GENWRAP
+VARx(int, fs_fd)
+VARx(ev_io, fs_w)
+VAR (fs_hash, ANFS fs_hash [EV_INOTIFY_HASHSIZE])
+#endif
+
 #undef VARx